@@ -3,7 +3,7 @@ from __future__ import annotations
 import os
 import re
 import sys
-from typing import Any, List
+from typing import Any
 
 from commitizen import factory, git, out
 from commitizen.config import BaseConfig
@@ -31,11 +31,12 @@ class Check:
         self.allow_abort: bool = bool(
             arguments.get("allow_abort", config.settings["allow_abort"])
         )
+        self.max_msg_length: int = arguments.get("message_length_limit", 0)
 
         # we need to distinguish between None and [], which is a valid value
 
         allowed_prefixes = arguments.get("allowed_prefixes")
-        self.allowed_prefixes: List[str] = (
+        self.allowed_prefixes: list[str] = (
             allowed_prefixes
             if allowed_prefixes is not None
             else config.settings["allowed_prefixes"]
@@ -53,13 +54,11 @@ class Check:
             for arg in (self.commit_msg_file, self.commit_msg, self.rev_range)
         )
         if num_exclusive_args_provided == 0 and not sys.stdin.isatty():
-            self.commit_msg: str | None = sys.stdin.read()
+            self.commit_msg = sys.stdin.read()
         elif num_exclusive_args_provided != 1:
             raise InvalidCommandArgumentError(
-                (
-                    "Only one of --rev-range, --message, and --commit-msg-file is permitted by check command! "
-                    "See 'cz check -h' for more information"
-                )
+                "Only one of --rev-range, --message, and --commit-msg-file is permitted by check command! "
+                "See 'cz check -h' for more information"
             )
 
     def __call__(self):
@@ -98,7 +97,7 @@ class Check:
         # Get commit message from file (--commit-msg-file)
         if self.commit_msg_file is not None:
             # Enter this branch if commit_msg_file is "".
-            with open(self.commit_msg_file, "r", encoding=self.encoding) as commit_file:
+            with open(self.commit_msg_file, encoding=self.encoding) as commit_file:
                 msg = commit_file.read()
         # Get commit message from command line (--message)
         elif self.commit_msg is not None:
@@ -108,7 +107,9 @@ class Check:
             return [git.GitCommit(rev="", title="", body=msg)]
 
         # Get commit messages from git log (--rev-range)
-        return git.get_commits(end=self.rev_range)
+        if self.rev_range:
+            return git.get_commits(end=self.rev_range)
+        return git.get_commits()
 
     @staticmethod
     def _filter_comments(msg: str) -> str:
@@ -147,4 +148,8 @@ class Check:
 
         if any(map(commit_msg.startswith, self.allowed_prefixes)):
             return True
+        if self.max_msg_length:
+            msg_len = len(commit_msg.partition("\n")[0].strip())
+            if msg_len > self.max_msg_length:
+                return False
         return bool(re.match(pattern, commit_msg))
